Class: RDF::RDFa::Format
- Inherits:
-
Format
- Object
- Format
- RDF::RDFa::Format
- Defined in:
- lib/rdf/rdfa/format.rb
Overview
RDFa format specification.
Class Method Summary collapse
-
.detect(sample) ⇒ Boolean
Sample detection to see if it matches RDFa (not RDF/XML or Microdata).
- .symbols ⇒ Object
Class Method Details
.detect(sample) ⇒ Boolean
Sample detection to see if it matches RDFa (not RDF/XML or Microdata)
Use a text sample to detect the format of an input file. Sub-classes implement a matcher sufficient to detect probably format matches, including disambiguating between other similar formats.
38 39 40 41 42 |
# File 'lib/rdf/rdfa/format.rb', line 38 def self.detect(sample) (sample.match(/<[^>]*(about|resource|prefix|typeof|property|vocab)\s*="[^>]*>/m) || sample.match(/<[^>]*DOCTYPE\s+html[^>]*>.*xmlns:/im) ) && !sample.match(/<(\w+:)?(RDF)/) end |
.symbols ⇒ Object
44 45 46 |
# File 'lib/rdf/rdfa/format.rb', line 44 def self.symbols [:rdfa, :lite, :html, :xhtml, :svg] end |